import React from 'react';

const LocationDetailsStep = ({ 
  roadTouch, 
  setRoadTouch,
  plotFacing, 
  setPlotFacing,
  distanceFromAirport,
  setDistanceFromAirport,
  distanceFromRailway,
  setDistanceFromRailway,
  distanceFromBusStand,
  setDistanceFromBusStand,
  distanceFromHospital,
  setDistanceFromHospital,
  distanceFromSchool,
  setDistanceFromSchool
}) => {
  const distanceItems = [
    { 
      icon: "✈️", 
      label: "Airport", 
      value: distanceFromAirport, 
      setter: setDistanceFromAirport 
    },
    { 
      icon: "🚂", 
      label: "Railway", 
      value: distanceFromRailway, 
      setter: setDistanceFromRailway 
    },
    { 
      icon: "🚌", 
      label: "Bus Stand", 
      value: distanceFromBusStand, 
      setter: setDistanceFromBusStand 
    },
    { 
      icon: "🏥", 
      label: "Hospital", 
      value: distanceFromHospital, 
      setter: setDistanceFromHospital 
    },
    { 
      icon: "🏫", 
      label: "School", 
      value: distanceFromSchool, 
      setter: setDistanceFromSchool 
    }
  ];

  return (
    <div className="space-y-4">
      <div>
        <label className="block mb-2 text-sm font-medium text-gray-700">
          Road Touch
        </label>
        <select 
          value={roadTouch}
          onChange={(e) => setRoadTouch(e.target.value)}
          className="w-full rounded-lg border border-gray-300 bg-transparent px-3 py-2 text-sm focus:border-purple-600 focus:outline-none sm:px-4 sm:py-2.5"
        >
          <option value="">Select Road Type</option>
          <option value="Expressway">Expressway</option>
          <option value="Highway">Highway</option>
          <option value="Main Road">Main Road</option>
          <option value="Internal Road">Internal Road</option>
        </select>
      </div>

      <div>
        <label className="block mb-2 text-sm font-medium text-gray-700">
          Plot Facing
        </label>
        <select
          value={plotFacing}
          onChange={(e) => setPlotFacing(e.target.value)}
          className="w-full rounded-lg border border-gray-300 bg-transparent px-3 py-2 text-sm focus:border-purple-600 focus:outline-none sm:px-4 sm:py-2.5"
        >
          <option value="">Select Facing</option>
          <option value="East">East</option>
          <option value="West">West</option>
          <option value="North">North</option>
          <option value="South">South</option>
        </select>
      </div>

      <div>
        <h3 className="text-sm font-medium text-gray-700 mb-2">Distance From</h3>
        <div className="space-y-3">
          {distanceItems.map((item) => (
            <div key={item.label} className="flex items-center space-x-2">
              <span className="text-lg">{item.icon}</span>
              <label className="flex-grow text-sm text-gray-600">{item.label}</label>
              <input
                type="text"
                value={item.value}
                onChange={(e) => item.setter(e.target.value)}
                placeholder={`Distance to ${item.label}`}
                className="w-full max-w-[200px] rounded-lg border border-gray-300 bg-transparent px-3 py-2 text-sm focus:border-purple-600 focus:outline-none"
              />
            </div>
          ))}
        </div>
      </div>
    </div>
  );
};

export default LocationDetailsStep;